<?php

declare(strict_types=1);

namespace Drupal\media_power_bi\Helper;

/**
 * Helper class for Power BI URL validation.
 */
final class MediaPowerBiHelper {

  /**
   * List of valid Power BI hostnames.
   */
  private const VALID_HOSTS = [
    'app.powerbi.com',
    'app.powerbigov.us',
    'app.high.powerbigov.us',
    'app.mil.powerbigov.us',
  ];

  /**
   * Validates whether the given URL is a supported Power BI embed link.
   *
   * @param string $url
   *   The URL to validate.
   *
   * @return bool
   *   TRUE if valid, FALSE otherwise.
   */
  public static function isValidPowerBiUrl(string $url): bool {
    $parsed = parse_url($url);
    return isset($parsed['host']) && in_array($parsed['host'], self::VALID_HOSTS, true);
  }

}
