<?php

declare(strict_types=1);

namespace Drupal\media_power_bi\Plugin\Validation\Constraint;

use Drupal\media_power_bi\Helper\MediaPowerBiHelper;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

/**
 * Validates Power BI embed code and URIs.
 */
class MediaPowerBiConstraintValidator extends ConstraintValidator {

  /**
   * {@inheritdoc}
   */
  public function validate($value, Constraint $constraint) {
    /** @var \Drupal\media\MediaInterface $media */
    $media = $value->getEntity();
    $source = $media->getSource();

    $url = $source->getSourceFieldValue($media);
    $url = trim($url, "/");
    // The URL may be NULL if the source field is empty, which is invalid input.
    if (empty($url)) {
      $this->context->addViolation($constraint->emptyUrlMessage);
      return;
    }

    if (!MediaPowerBiHelper::isValidPowerBiUrl($url)) {
      $this->context->addViolation($constraint->invalidUrlMessage);
    }
  }

}
